@@ -46,7 +46,6 @@ class ApplyWorkflowBase(SQLModel):
     output_dataset_id: Optional[int]
     workflow_id: Optional[int]
     overwrite_input: bool = False
-    username: Optional[str] = None
     worker_init: Optional[str] = None
 
 
@@ -170,7 +169,7 @@ class ResourceTypeEnum(str, Enum):
 
 
 class TaskBase(SQLModel):
-    name: str = Field(sa_column_kwargs=dict(unique=True))
+    name: str
     resource_type: ResourceTypeEnum
     module: Optional[str]
     input_type: str
